@@ -20,6 +20,8 @@
 #include <QMenu>
 #include <QDesktopServices>
 #include <QUrl>
+#include <QApplication>
+#include <QDesktopWidget>
 
 #include "geticon.h"
 #include "theme.h"
@@ -27,12 +29,30 @@
 Browser::Browser( const QString home, bool showToolBar, QWidget* parent)
     : QMainWindow( parent)
 {
+isClosed=false;
 setWindowTitle("Texmaker");
 #if defined(Q_OS_MAC)
 setWindowIcon(QIcon(":/images/logo128.png"));
 #else
 setWindowIcon(getIcon(":/images/appicon.png"));
 #endif
+
+#ifdef USB_VERSION
+QSettings *config=new QSettings(QCoreApplication::applicationDirPath()+"/texmakerhtmlview.ini",QSettings::IniFormat); //for USB-stick version :
+#else
+QSettings *config=new QSettings(QSettings::IniFormat,QSettings::UserScope,"xm1","texmakerhtmlview");
+#endif
+config->beginGroup( "htmlviewer" );
+QRect screen = QApplication::desktop()->screenGeometry();
+int w= config->value( "Geometries/MainwindowWidth",screen.width()/2).toInt();
+int h= config->value( "Geometries/MainwindowHeight",screen.height()-150).toInt() ;
+int x= config->value( "Geometries/MainwindowX",screen.width()/2).toInt();
+int y= config->value( "Geometries/MainwindowY",30).toInt() ;
+resize(w,h);
+move(x,y);
+windowstate=config->value("MainWindowState").toByteArray();
+config->endGroup();
+
 progress = 0;
 view = new QWebEngineView(this);
 if ( !home.isEmpty()) view->load(QUrl(home));
@@ -53,6 +73,7 @@ if (showToolBar)
     QToolBar *toolBar = addToolBar("Navigation");
     toolBar->setIconSize(QSize(22,22 ));
     toolBar->setStyleSheet(Theme::viewportLightStyleSheet);
+    toolBar->setObjectName("Navigation");
     QAction *Act;
     Act = new QAction(getIcon(":/images/home.png"), tr("Index"), this);
     connect(Act, SIGNAL(triggered()), this, SLOT(Index()));
@@ -79,7 +100,7 @@ if (showToolBar)
 setCentralWidget(view);
 setUnifiedTitleAndToolBarOnMac(true);
 //if ( !home.isEmpty()) view->setUrl(QUrl(home));
-//resize(780,580 );
+restoreState(windowstate);
 }
 
 Browser::~Browser()
@@ -87,6 +108,24 @@ Browser::~Browser()
 
 }
 
+void Browser::closeEvent(QCloseEvent *e)
+{
+#ifdef USB_VERSION
+QSettings config(QCoreApplication::applicationDirPath()+"/texmakerhtmlview.ini",QSettings::IniFormat); //for USB-stick version 
+#else
+QSettings config(QSettings::IniFormat,QSettings::UserScope,"xm1","texmakerhtmlview");
+#endif
+config.beginGroup( "htmlviewer" );
+config.setValue("MainWindowState",saveState());
+config.setValue("Geometries/MainwindowWidth", width() );
+config.setValue("Geometries/MainwindowHeight", height() );
+config.setValue("Geometries/MainwindowX", x() );
+config.setValue("Geometries/MainwindowY", y() );
+config.endGroup();
+isClosed=true;
+e->accept();
+}
+
 void Browser::adjustTitle()
 {
 if (progress <= 0 || progress >= 100)
