@@ -24,6 +24,7 @@ class Browser : public QMainWindow
 public:
     Browser( const QString home, bool showToolBar=true, QWidget* parent = 0);
     ~Browser();
+    bool isClosed;
 
 protected slots:
     void adjustTitle();
@@ -34,6 +35,8 @@ private slots:
   void Print();
   void Find();
 private:
+    void closeEvent(QCloseEvent *e);
+    QByteArray windowstate;
     QWebEngineView *view;
     int progress;
     QLineEdit *searchLineEdit;
