@@ -318,8 +318,11 @@ void PageItem::setPhysicalDpi(int physicalDpiX, int physicalDpiY)
     {
         refresh();
 
-        m_physicalDpiX = physicalDpiX;
-        m_physicalDpiY = physicalDpiY;
+        //m_physicalDpiX = physicalDpiX;
+        //m_physicalDpiY = physicalDpiY;
+        
+        m_physicalDpiX = qMax(physicalDpiX,physicalDpiY); // force square pixels -- workaround for Xorg on non-4:3 and non-16:9 screens.
+        m_physicalDpiY = qMax(physicalDpiX,physicalDpiY);
 
         prepareGeometryChange();
         prepareGeometry();
