@@ -40,6 +40,7 @@
 PdfViewer::PdfViewer( const QString fileName, const QString externalCommand, const QString ghostscriptCommand, const QString lpopt,const QKeySequence edfocus,const QString SpellLang, const qreal startScale, QWidget* parent)
     : QMainWindow( parent)
 {
+isClosed=false;
 setWindowTitle("Texmaker : pdf preview");
 #if defined(Q_OS_MAC)
 setWindowIcon(QIcon(":/images/logo128.png"));
@@ -61,8 +62,9 @@ int y= config->value( "Geometries/MainwindowY",30).toInt() ;
 resize(w,h);
 move(x,y);
 windowstate=config->value("MainWindowState").toByteArray();
+showingListPages=config->value( "Gui/ListPages",true).toBool();
 config->endGroup();
-
+//restoreState(windowstate);
 spell_lang=SpellLang;
 KeySequenceEditorFocus=edfocus;
 setCorner(Qt::TopLeftCorner, Qt::LeftDockWidgetArea);
@@ -134,8 +136,8 @@ StructureTreeView->setStyleSheet(Theme::treeviewStyleSheet);
 connect(LeftPanelToolBar->addAction(getIcon(":/images/structure.png"),tr("Structure")), SIGNAL(triggered()), this, SLOT(ShowStructure()));
 LeftPanelStackedWidget->addWidget(StructureTreeView);
 
-showingListPages=true;
-ShowListPages();
+
+
 
 LeftPanelLayout->setSpacing(0);
 LeftPanelLayout->setMargin(0);
@@ -175,7 +177,7 @@ editMenu->addAction(findAct);
 
 
 
-QToolBar *toolBar = addToolBar("Pdf controls");
+toolBar = addToolBar("Pdf controls");
 toolBar->setObjectName("Pdf controls");
 toolBar->setStyleSheet(Theme::toolbarlightStyleSheet);
 
@@ -299,7 +301,10 @@ rotateLeftAction->setEnabled(false);
 rotateRightAction->setEnabled(false);
 presentationAction->setEnabled(false);
 
-restoreState(windowstate, 0);
+restoreState(windowstate);
+
+//restoreDockWidget(StructureView);
+if (showingListPages) ShowListPages();
 openFile(pdf_file,viewpdf_command,gswin32c_command);
 }
 
@@ -321,12 +326,15 @@ QSettings config(QCoreApplication::applicationDirPath()+"/texmakerpdfview.ini",Q
 QSettings config(QSettings::IniFormat,QSettings::UserScope,"xm1","texmakerpdfview");
 #endif
 config.beginGroup( "pdfviewer" );
-config.setValue("MainWindowState",saveState(0));
+config.setValue("MainWindowState",saveState());
 config.setValue("Geometries/MainwindowWidth", width() );
 config.setValue("Geometries/MainwindowHeight", height() );
 config.setValue("Geometries/MainwindowX", x() );
 config.setValue("Geometries/MainwindowY", y() );
+config.setValue("Gui/ListPages",showingListPages);
 config.endGroup();
+isClosed=true;
+e->accept();
 }
 
 void PdfViewer::openFile(QString fn,QString ec,QString pc)
