@@ -50,6 +50,7 @@ public:
     PdfViewer( const QString fileName, const QString externalCommand, const QString ghostscriptCommand, const QString lpopt,const QKeySequence edfocus, const QString SpellLang, const qreal startScale, QWidget* parent = 0);
     ~PdfViewer();
     QString pdf_file;
+    bool isClosed;
 public slots:
 void openFile(QString fn, QString ec,QString pc);
 void jumpToPdfFromSource(QString sourceFile,int source_line, int source_col);
@@ -61,7 +62,7 @@ void closeEvent(QCloseEvent *e);
 QKeySequence KeySequenceEditorFocus;
 QStackedWidget *LeftPanelStackedWidget;
 QTreeView *StructureTreeView;
-QToolBar *LeftPanelToolBar;
+QToolBar *LeftPanelToolBar, *toolBar;
 QHBoxLayout *LeftPanelLayout,*CentralLayout;
 QByteArray windowstate;
 
