@@ -35,14 +35,14 @@ VersionDialog::~VersionDialog(){
 
 void VersionDialog::gotoDownloadPage()
 {
-QDesktopServices::openUrl(QUrl("http://www.xm1math.net/texmaker/download.html"));
+QDesktopServices::openUrl(QUrl("https://www.xm1math.net/texmaker/download.html"));
 }
 
 void VersionDialog::launchChecker()
 {
 ui.pushButtonCheck->setEnabled(false);
 timer.start(10000);
-reply = manager.get (  QNetworkRequest(QUrl("http://www.xm1math.net/texmaker/version.txt"))  );
+reply = manager.get (  QNetworkRequest(QUrl("https://www.xm1math.net/texmaker/version.txt"))  );
 QObject::connect (reply, SIGNAL (finished()),this, SLOT(showResultChecker()));
 }
 
